==> beacon_0_1_1.tar.tgz: beacon/beacon/template/index.tpl.php <==
<?php
if (isset($item)) {
?>

<div style="width:100%;display: block">
	<span class="txt_item_title">
	<?php echo $item['item_title'];?>
	</span>
	<?php echo $item['item_body_display'];?>
</div>

<p>
<div id="author">
<?php
if (isset($item['item_edit_datetime'])) {
?>
<?php echo $lang['txt_last_edited'];?>:&nbsp;<?php echo $item['item_edit_datetime'];?>
<?php
}
elseif (isset($item['item_create_datetime'])) {
?>
<?php echo $lang['txt_created'];?>:&nbsp;<?php echo $item['item_create_datetime'];?>
<?php }?>


&nbsp;
<a href="print.php?item_id=<?php echo $item['item_id'];?>"><?php echo $lang['href_print'];?></a>
<?php
if ($this->user->checkPermission($permissions['edit_item'])) {
?>
&nbsp;
<a href="admin.php?item_id=<?php echo $item['item_id'];?>"><?php echo $lang['href_edit_this'];?></a>
<?php }?>
<br />
</div>
</p>
<?php }?>




<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" alt="" /><br />

<div id="comment">	
<table width="100%" cellpadding="0" cellspacing="0" border="0">
	<tr>
		<td colspan="3">
			<span class="txt_item_title">
			<?php echo $lang['hdr_comments'];?><br />
			</span>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
		</td>
	</tr>
	<?php
	if (isset($comments)) {
	foreach($comments as $key => $i):
	?>
	<tr>
		<td valign="top">
			<table width="100%" cellpadding="2" cellspacing="0" border="0">
				<tr>
					<td class="header_box">
						<?php echo $i['comment_create_datetime'];?>
						&nbsp;|&nbsp;
						<?php echo $i['user_name'];?>
						&nbsp;|&nbsp;
						<?php 
						if (!empty($i['show_email'])){
							echo $i['user_email'];
						}
						else {
							echo $lang['txt_email_withheld'];
						}
						?>
						<br />
					</td>
				</tr>
				<tr>
					<td valign="top" class="comment_box">
						<?php echo $i['comment_body'];?><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
	<tr>
		<td colspan="2">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
		</td>
	</tr>
	<?php
	endforeach;
	}
	else {
	?>
	<tr>
		<td colspan="2">
			<?php echo $lang['err_no_comments'];?><br />
		</td>
	</tr>
	<?php }?>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />


<?php
if (isset($item) && $item['allow_comment'] == 1) {
?>	
	<div class="comment_form">
		<form action="index.php" method="post" name="comment">
		<input type="hidden" name="item_id" value="<?php echo $item['item_id'];?>" />
		
		<table width="100%" cellpadding="2" cellspacing="0" border="0">
			<?php
			if (isset($display) && $display == "preview_comment") {
			?>
			<tr>
				<td valign="top">
					<input type="hidden" name="comment_body" value="<?php echo $comment['comment_body'];?>" />
					<?php echo $comment['display_comment_body'];?><br />
				</td>
			</tr>
			<tr>
				<td align="right">
					<input type="submit" name="edit_comment_again" class="button_urgent" value="<?php echo $lang['form_submit_edit_again'];?>" />&nbsp;&nbsp;
					<input type="submit" name="insert_comment" class="button_urgent" value="<?php echo $lang['form_submit_save'];?>" /><br />
				</td>
			</tr>
			<?php
			}
			else {
			?>
	
			<tr>
				<td>
					<b><label for="id_comment" style="width:100%"><?php echo $lang['hdr_add_comment'];?></label></b><br />
				</td>
			</tr>
			<tr>
				<td>
					<?php echo $lang['txt_comment_help'];?><br />
				</td>
			</tr>
			<tr>
				<td>
					<textarea id="id_comment" name="comment_body" rows="4" cols="70"><?php if(isset($comment['comment_body'])) { echo $comment['comment_body'];}?></textarea><br />
				</td>
			</tr>
			<tr>
				<td align="right">
					<?php if (isset($allow_spellcheck)) {?>
					<input type="button" value="<?php echo $lang['form_submit_spelling'];?>" class="button_urgent" onClick="openSpellChecker();" />&nbsp;&nbsp;
					<?php }?>
					<input type="submit" name="preview_comment" class="button_urgent" value="<?php echo $lang['form_submit_preview'];?>" />&nbsp;&nbsp;
					<input type="submit" name="insert_comment" class="button_urgent" value="<?php echo $lang['form_submit_add'];?>" /><br />
				</td>
			</tr>
			<?php }?>
		</table>
		</form>
		</div>
<?php }?>

==> beacon_0_1_6.tar.tgz: beacon/beacon/template/index.tpl.php <==
<?php
if (isset($item)) {
?>

<div style="width:100%;display: block">
	<span class="txt_item_title">
	<?php echo $item['item_title'];?>
	</span>
	<?php echo $item['item_body_display'];?>
</div>

<p>
<div id="author">
<?php
if (isset($item['item_edit_datetime'])) {
?>
<?php echo $lang['txt_last_edited'];?>:&nbsp;<?php echo $item['item_edit_datetime'];?>
<?php
}
elseif (isset($item['item_create_datetime'])) {
?>
<?php echo $lang['txt_created'];?>:&nbsp;<?php echo $item['item_create_datetime'];?>
<?php }?>


&nbsp;
<a href="print.php?item_id=<?php echo $item['item_id'];?>"><?php echo $lang['href_print'];?></a>
<?php
if ($this->user->checkPermission($permissions['edit_item'])) {
?>
&nbsp;
<a href="admin.php?item_id=<?php echo $item['item_id'];?>"><?php echo $lang['href_edit_this'];?></a>
<?php }?>
<br />
</div>
</p>
<?php }?>



<?php
if (isset($comments) || (isset($item) && $item['allow_comment'] == 1)) {
?>
<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" alt="" /><br />

<div id="comment">	
<table width="100%" cellpadding="0" cellspacing="0" border="0">
	<tr>
		<td colspan="3">
			<span class="txt_item_title">
			<?php echo $lang['hdr_comments'];?><br />
			</span>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
		</td>
	</tr>
	<?php
	if (isset($comments)) {
	foreach($comments as $key => $i):
	?>
	<tr>
		<td valign="top">
			<table width="100%" cellpadding="2" cellspacing="0" border="0">
				<tr>
					<td class="header_box">
						<?php echo $i['comment_create_datetime'];?>
						&nbsp;&#124;&nbsp;
						<?php echo $i['user_name'];?>
						&nbsp;&#124;&nbsp;
						<?php 
						if (!empty($i['show_email'])){
							echo $i['user_email'];
						}
						else {
							echo $lang['txt_email_withheld'];
						}
						?>
						<br />
					</td>
				</tr>
				<tr>
					<td valign="top" class="comment_box">
						<?php echo $i['comment_body'];?><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
	<tr>
		<td colspan="2">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
		</td>
	</tr>
	<?php
	endforeach;
	}
	else {
	?>
	<tr>
		<td colspan="2">
			<?php echo $lang['err_no_comments'];?><br />
		</td>
	</tr>
	<?php }?>
	
	<?php
	if (isset($item)) {
	?>
	<tr>
		<td colspan="2" align="right" id="author">
			<?php
			if (isset($_REQUEST['ico'])) {
			?>
			<a href="index.php?item_id=<?php echo $item['item_id'];?>"><?php echo $lang['href_all_comments'];?></a>&nbsp;<br />
			<?php
			}
			else {
			?>
			<a href="index.php?item_id=<?php echo $item['item_id'];?>&amp;ico=1"><?php echo $lang['href_item_comments_only'];?></a>&nbsp;<br />
			<?php }?>
		<br />
		</td>
	</tr>
	<?php }?>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />


<?php
if (isset($_SESSION['user_id']) && isset($item) && $item['allow_comment'] == 1) {
?>	
	<div class="comment_form">
		<form action="index.php" method="post" name="comment">
		<input type="hidden" name="item_id" value="<?php echo $item['item_id'];?>" />
		
		<table width="100%" cellpadding="2" cellspacing="0" border="0">
			<?php
			if (isset($display) && $display == "preview_comment") {
			?>
			<tr>
				<td valign="top">
					<input type="hidden" name="comment_body" value="<?php echo $comment['comment_body'];?>" />
					<?php echo $comment['display_comment_body'];?><br />
				</td>
			</tr>
			<tr>
				<td align="right">
					<input type="submit" name="edit_comment_again" class="button" value="<?php echo $lang['form_submit_edit_again'];?>" />&nbsp;&nbsp;
					<input type="submit" name="insert_comment" class="button" value="<?php echo $lang['form_submit_save'];?>" /><br />
				</td>
			</tr>
			<?php
			}
			else {
			?>
	
			<tr>
				<td>
					<b><label for="id_comment" style="width:100%"><?php echo $lang['hdr_add_comment'];?></label></b><br />
				</td>
			</tr>
			<tr>
				<td>
					<?php echo $lang['txt_comment_help'];?><br />
				</td>
			</tr>
			<tr>
				<td>
					<textarea id="id_comment" name="comment_body" rows="4" cols="70"><?php if(isset($comment['comment_body'])) { echo $comment['comment_body'];}?></textarea><br />
				</td>
			</tr>
			<tr>
				<td align="right">
					<?php if (isset($allow_spellcheck)) {?>
					<input type="button" value="<?php echo $lang['form_submit_spelling'];?>" class="button" onClick="openSpellChecker();" />&nbsp;&nbsp;
					<?php }?>
					<input type="submit" name="preview_comment" class="button" value="<?php echo $lang['form_submit_preview'];?>" />&nbsp;&nbsp;
					<input type="submit" name="insert_comment" class="button" value="<?php echo $lang['form_submit_add'];?>" /><br />
				</td>
			</tr>
			<?php }?>
		</table>
		</form>
		</div>
<?php 
}
elseif (!isset($_SESSION['user_id']) && isset($item) && $item['allow_comment'] == 1) { 
?>
<div class="header_box">
	<?php echo $lang['txt_comment_leave_help'];?><br />
</div>
<?php }?>
<?php }?>
